var winston;
var Syslog;
var logger;

module.exports = {

    info : function(message){
        if(Syslog){
            Syslog.log(Syslog.LOG_INFO, message);
        }else {
            logger.info(message);
        }
    },

    debug : function(message){
        if(Syslog){
            Syslog.log(Syslog.LOG_DEBUG, message);
        }else {
            logger.debug(message);
        }
    },

    error : function(message){
        if(Syslog){
            Syslog.log(Syslog.LOG_ERROR, message);
        }else {
            logger.error(message);
        }
    },

    init : function(conf, projectName){
        // node syslog is used only for linux environments (development and production)
        if(process.platform === 'linux'){
            Syslog = require('node-syslog');
            Syslog.init(projectName, Syslog.LOG_PID | Syslog.LOG_ODELAY, Syslog.LOG_LOCAL0);
        }else{
            winston = require('winston');

            winston.emitErrs = true;

            var monthNames = ["jan", "feb", "mar", "apr", "may", "jun",
                "jul", "aug", "sep", "oct", "nov", "dec"
            ];
            var infoLogPath = conf.log.path + conf.log.info + monthNames[new Date().getMonth()] + '-info.log';
            var debugLogPath = conf.log.path + conf.log.debug + monthNames[new Date().getMonth()] + '-debug.log';
            var errorLogPath = conf.log.path + conf.log.error + monthNames[new Date().getMonth()] + '-error.log';

            logger = new winston.Logger({
                transports: [
                    new winston.transports.File({
                        name: 'file#info',
                        level: 'info',
                        filename: infoLogPath,
                        handleExceptions: true,
                        json: true,
                        maxsize: 5242880, //5MB
                        maxFiles: 5,
                        colorize: true
                    }),
                    new winston.transports.File({
                        name: 'file#debug',
                        level: 'debug',
                        filename: debugLogPath,
                        handleExceptions: true,
                        json: true,
                        maxsize: 5242880, //5MB
                        maxFiles: 5,
                        colorize: true
                    }),
                    new winston.transports.File({
                        name: 'file#error',
                        level: 'error',
                        filename: errorLogPath,
                        handleExceptions: true,
                        json: true,
                        maxsize: 5242880, //5MB
                        maxFiles: 5,
                        colorize: true
                    })
                ],
                exitOnError: false
            });
        }
    }

};

